[][src]Enum mpeg2ts_reader::demultiplex::DemuxError

pub enum DemuxError {
    NotEnoughData {
        field: &'static str,
        expected: usize,
        actual: usize,
    },
}

TODO: this type does not belong here

Variants

NotEnoughData

The transport stream has a syntax error that means there was not enough data present to parse the requested structure.

Fields of NotEnoughData

field: &'static str

The name of the field we were unable to parse

expected: usize

The expected size of the field data

actual: usize

the actual size of date available within the transport stream