[−][src]Enum mpeg2ts_reader::demultiplex::FilterRequest
Request that may be submitted to a
DemuxContext::construct() implementation.
Variants
ByPid(Pid)requests a filter implementation for handling a PID contained in the transport stream that was not announced via other means (PAT/PMT).
ByStreamrequests a filter for the stream with the given details which has just been discovered within a Program Map Table section.
Fields of ByStream
program_pid: PidThe Pid of the program containing the stream to be handled
stream_type: StreamTypeThe type of the stream to be handled
pmt: &'a PmtSection<'buf>The full PmtSection defining the stream needing to he handled
stream_info: &'a StreamInfo<'buf>the PMT stream information for the specific stream being handled (which will be one
of the values inside the pmt which is also provided.
PmtRequests a filter implementation for handling Program Map Table sections
Fields of Pmt
Nitrequests a filter implementation to handle packets containing Network Information Table data
Fields of Nit
pid: PidThe Pid of the packets which contain the NIT.