[−][src]Struct mpeg2ts_reader::demultiplex::NullPacketFilter
No-op implementation of PacketFilter.
Sometimes a Transport Stream will contain packets that you know you want to ignore. This type can be used when you have to register a filter for such packets with the demultiplexer.