[][src]Struct mpeg2ts_reader::demultiplex::PatPacketFilter

pub struct PatPacketFilter<Ctx: DemuxContext> { /* fields omitted */ }

PacketFilter implementation which will insert some other PacketFilter into the Demultiplex instance for each program listed in the stream's PAT-section.

The particular PacketFilter to be inserted is determined by querying DemuxContext::construct(), passing a FilterRequest::Pmt request.