[][src]Struct mpeg2ts_reader::demultiplex::PmtPacketFilter

pub struct PmtPacketFilter<Ctx: DemuxContext + 'static> { /* fields omitted */ }

PacketFilter implementation which will insert some other PacketFilter into the Demultiplex instance for each sub-stream listed in one of the stream's PMT-sections.

The particular PacketFilter to be inserted is determined by querying DemuxContxt::construct(), passing a FilterRequest::ByStream request.

Methods

impl<Ctx: DemuxContext> PmtPacketFilter<Ctx>[src]

pub fn new(pid: Pid, program_number: u16) -> PmtPacketFilter<Ctx>[src]

creates a new PmtPacketFilter for PMT sections in packets with the given Pid, and for the given program number.