[][src]Enum mpeg2ts_reader::descriptor::DescriptorError

pub enum DescriptorError {
    NotEnoughData {
        tag: u8,
        actual: usize,
        expected: usize,
    },
    TagTooLongForBuffer {
        taglen: usize,
        buflen: usize,
    },
    BufferTooShort {
        buflen: usize,
    },
    UnhandledTagValue(u8),
}

An error during parsing of a descriptor

Variants

NotEnoughData

The amount of data available in the buffer is not enough to hold the descriptor's declared size.

Fields of NotEnoughData

tag: u8

descriptor tag value

actual: usize

actual buffer size

expected: usize

expected buffer size

TagTooLongForBuffer

TODO: replace with NotEnoughData

Fields of TagTooLongForBuffer

taglen: usize

actual length in descriptor header

buflen: usize

remaining bytes in buffer (which is seen to be shorter than taglen)

BufferTooShort

The buffer is too short to even hold the two bytes of generic descriptor header data

Fields of BufferTooShort

buflen: usize

the actual buffer length

UnhandledTagValue(u8)

There is no mapping defined of the given descriptor tag value to a Descriptor value.