[−][src]Struct mpeg2ts_reader::descriptor::iso_639_language::Language
One of potentially many pieces of language metadata within an Iso639LanguageDescriptor.
Methods
impl<'buf> Language<'buf>[src]
pub fn code(&self, trap: DecoderTrap) -> Result<String, Cow<'static, str>>[src]
Returns a string containing the ISO-639 language code of the elementary stream to which this descriptor is attached.
pub fn audio_type(&self) -> AudioType[src]
Returns an AudioType variant indicating what role this audio track plays within the
program.