[][src]Struct mpeg2ts_reader::descriptor::UnknownDescriptor

pub struct UnknownDescriptor<'buf> {
    pub tag: u8,
    pub payload: &'buf [u8],
}

Catch-all type for when there is no explicit handling for the given descriptor type.

Fields

tag: u8

the descriptor's identifying 'tag' value; different types of descriptors are assigned different tag values

payload: &'buf [u8]

the descriptor's payload bytes

Methods

impl<'buf> UnknownDescriptor<'buf>[src]

pub fn new(
    tag: u8,
    payload: &'buf [u8]
) -> Result<UnknownDescriptor<'buf>, DescriptorError>
[src]

Constructor, in the form required for use with the descriptor_enum!{} macro.