Enum mpeg2ts_reader::StreamType [−][src]
The types of Elementary Stream specified in ISO/IEC 13818-1.
As returned by
StreamInfo::stream_type().
Variants
ISO/IEC 11172 Video
ITU-T Rec. H.262 | ISO/IEC 13818-2 Video or ISO/IEC 11172-2 constrained parameter video stream
ISO/IEC 11172 Audio
ISO/IEC 13818-3 Audio
ITU-T Rec. H.222.0 | ISO/IEC 13818-1 private_sections
ITU-T Rec. H.222.0 | ISO/IEC 13818-1 PES packets containing private data
ISO/IEC 13522 MHEG
ITU-T Rec. H.222.0 | ISO/IEC 13818-1 Annex A DSM-CC
ITU-T Rec. H.222.1
ISO/IEC 13818-6 DSM CC multiprotocol encapsulation
ISO/IEC 13818-6 DSM CC U-N messages
ISO/IEC 13818-6 DSM CC stream descriptors
ISO/IEC 13818-6 DSM CC tabled data
ITU-T Rec. H.222.0 | ISO/IEC 13818-1 auxiliary
ISO/IEC 13818-7 Audio with ADTS transport syntax
ISO/IEC 14496-2 Visual
ISO/IEC 14496-3 Audio with the LATM transport syntax as defined in ISO/IEC 14496-3 / AMD 1
ISO/IEC 14496-1 SL-packetized stream or FlexMux stream carried in PES packets
ISO/IEC 14496-1 SL-packetized stream or FlexMux stream carried in ISO/IEC14496_sections.
ISO/IEC 13818-6 Synchronized Download Protocol
Metadata carried in PES packets
Metadata carried in metadata_sections
Metadata carried in ISO/IEC 13818-6 Data Carousel
Metadata carried in ISO/IEC 13818-6 Object Carousel
Metadata carried in ISO/IEC 13818-6 Synchronized Download Protocol
IPMP stream (defined in ISO/IEC 13818-11, MPEG-2 IPMP)
AVC video stream as defined in ITU-T Rec. H.264 | ISO/IEC 14496-10 Video
ISO/IEC 14496-3 Audio, without using any additional transport syntax, such as DST, ALS and SLS
ISO/IEC 14496-17 Text
ITU-T Rec. H.265 and ISO/IEC 23008-2
Chinese Video Standard
Dolby Digital (AC-3) audio for ATSC
ATSC Data Service Table, Network Resources Table
PES packets containing ATSC streaming synchronous data
Private(u8)0xc3-0xff privately defined,
Reserved(u8)Reserved for use in future standards
Implementations
impl StreamType[src]
pub fn is_pes(self) -> bool[src]
true if packets of a stream with this stream_type will carry data in Packetized
Elementary Stream format.