[][src]Enum mpeg2ts_reader::packet::AdaptationFieldError

pub enum AdaptationFieldError {
    FieldNotPresent,
    NotEnoughData,
    SpliceTimestampError(TimestampError),
}

Some error encountered while parsing adaptation field syntax

Variants

FieldNotPresent

The an optional field's value was requested, but the field is not actually present

NotEnoughData

There is a syntactic problem in the adaptation field being parsed, and not enough data is present in the stream to hold the requested component which is supposed to be present.

SpliceTimestampError(TimestampError)

The seamless_splice() function found a syntax error is the adaptation field data holding the seamless_splice field.