[][src]Enum mpeg2ts_reader::packet::TransportScramblingControl

pub enum TransportScramblingControl {
    NotScrambled,
    Undefined(u8),
}

Indicates content scrambling in use, if any.

Actual content scrambling schemes, indicates through the u8 value in the Unefined variant, are undefined in the main TS spec (left to be described by other specifications).

Variants

NotScrambled

The stream is not scrambled.

Undefined(u8)

The stream is scrambled using a scheme not defined in the TS spec.