[][src]Struct mpeg2ts_reader::packet::Pid

pub struct Pid(_);

A Packet Identifier value, between 0x0000 and 0x1fff.

PID values identify a particular sub-stream within the overall Transport Stream.

As returned by the Packet::pid method for example.

Methods

impl Pid[src]

pub const MAX_VALUE: u16[src]

The largest possible PID value, 0x1fff.

pub const PID_COUNT: usize[src]

The total number of distinct PID values, 0x2000 (equal to MAX_VALUE + 1)

pub const PAT: Pid[src]

The identifier of TS Packets containing Program Association Table sections, with value 0.

pub const STUFFING: Pid[src]

The identifier of TS Packets containing 'stuffing' data, with value 0x1fff

pub fn new(pid: u16) -> Pid[src]

Panics if the given value is greater than Pid::MAX_VALUE.