[][src]Enum mpeg2ts_reader::pes::Copyright

pub enum Copyright {
    Protected,
    Undefined,
}

Indicates the copyright status of the contents of the Elementary Stream packet.

Returned by PesParsedContents.copyright()

Variants

Protected

Content of this Elementry Stream is protected by copyright

Undefined

Copyright protection of the content of this Elementary Stream is not defined