[][src]Enum mpeg2ts_reader::pes::DataAlignment

pub enum DataAlignment {
    Aligned,
    NotAligned,
}

Indicates if the start of some 'unit' of Elementary Stream content is immediately at the start of the PES packet payload.

Returned by PesParsedContents.data_alignment_indicator()

Variants

Aligned

Access Units are aligned to the start of the PES packet payload

NotAligned

Access Units are might not be aligned to the start of the PES packet payload