[][src]Enum mpeg2ts_reader::pes::FrequencyTruncationCoefficientSelection

pub enum FrequencyTruncationCoefficientSelection {
    DCNonZero,
    FirstThreeNonZero,
    FirstSixNonZero,
    AllMaybeNonZero,
}

Indication of the restricted set of coefficients that may have been used to encode the video, specified within DsmTrickMode.

Variants

DCNonZero

Only DC coefficients are non-zero

FirstThreeNonZero

Only the first three coefficients are non-zero

FirstSixNonZero

Only the first six coefficients are non-zero

AllMaybeNonZero

All coefficients may be non-zero