PesError

Enum PesError 

pub enum PesError {
    FieldNotPresent,
    PtsDtsFlagsInvalid,
    NotEnoughData {
        requested: usize,
        available: usize,
    },
    MarkerBitNotSet,
}
Errors which may be encountered while processing PES data.

Variants



FieldNotPresent

The value of an optional field was requested, but the field is not actually present in the given PES data



PtsDtsFlagsInvalid

The pts_dts_flags field of the PES packet signals that DTS is present and PTS is not, which not a valid combination



NotEnoughData

There is not enough data in the buffer to hold the expected syntax element

Fields

requested: usize

the number of bytes required to hold the requested syntax element

available: usize

the number of bytes actually remaining in the buffer



MarkerBitNotSet

Marker bits are expected to always have the value 1 – the value 0 presumably implies a parsing error.