[][src]Enum mpeg2ts_reader::pes::PtsDts

pub enum PtsDts {
    None,
    PtsOnly(Result<Timestamp, TimestampError>),
    Invalid,
    Both {
        pts: Result<Timestamp, TimestampError>,
        dts: Result<Timestamp, TimestampError>,
    },
}

Contains some combination of PTS and DTS timestamps (or maybe neither).

The timestamps will be wrapped in Result, in case an error in the stored timestamp syntax means that it can't be decoded.

Variants

None

There are no timestamps present

PtsOnly(Result<Timestamp, TimestampError>)

Only Presentation Time Stamp is present

Invalid

the pts_dts_flags field contained an invalid value

Both

Both Presentation and Decode Time Stamps are present

Fields of Both

pts: Result<Timestamp, TimestampError>

Presentation Time Stamp

dts: Result<Timestamp, TimestampError>

Decode Time Stamp