[−][src]Struct mpeg2ts_reader::pes::PesHeader
Header at the start of every PES packet.
The header identifies,
- The stream identifier, returned by
stream_id() - The the size of the packet, returned by
pes_packet_length(), which may well be larger than the size of the payload buffer obtained from the header (the payload is likely split across multiple Transport Stream packets)
In addition, the header may provide access to either
- an additional set of header data followed by a payload, when
contents()returnsPesContents::Parsed - just a payload on its own, when
contents()returnsPesContents::Payload
Methods
impl<'buf> PesHeader<'buf>[src]
pub fn from_bytes(buf: &'buf [u8]) -> Option<PesHeader<'buf>>[src]
Wraps the given slice in a PesHeader, which will then provide method to parse the header fields within the slice.
Returns None if the buffer is too small to hold the PES header, or if the PES
'start code prefix' is missing.
TODO: should probably return Result.
pub fn stream_id(&self) -> StreamId[src]
Indicator of the type of stream per ISO/IEC 13818-1, Table 2-18.
pub fn pes_packet_length(&self) -> PesLength[src]
The overall length of the PES packet, once all pieces from the transport stream have been collected.
pub fn contents(&self) -> PesContents<'buf>[src]
Either PesContents::Parsed, or PesContents::Payload, depending on the value of
stream_id()