Timestamp

Struct Timestamp 

pub struct Timestamp { /* private fields */ }
A 33-bit Elementary Stream timestamp, used to represent PTS and DTS values which may appear in an Elementary Stream header.

Implementations

Source

impl Timestamp

pub const MAX: Timestamp

The largest representable timestamp value before the timestamp wraps back around to zero.

pub const TIMEBASE: u64 = 90_000

90kHz timebase in which PTS and DTS values are measured.

pub fn from_pts_bytes(buf: &[u8]) -> Result<Timestamp, TimestampError>

Parse a Presentation Time Stamp value from the 5 bytes at the start of the given slice

Panics if fewer than 5 bytes given

pub fn from_dts_bytes(buf: &[u8]) -> Result<Timestamp, TimestampError>

Parse a Decode Time Stamp value from the 5 bytes at the start of the given slice

Panics if fewer than 5 bytes given

pub fn from_bytes(buf: &[u8]) -> Result<Timestamp, TimestampError>

Parse a Time Stamp value from the 5 bytes at the start of the given slice, without checking the 4-bit prefix for any particular value (the from_pts_bytes() and from_dts_bytes() methods, in contrast, do check that the expected prefix bits are present).

Panics if fewer than 5 bytes given

pub fn from_u64(val: u64) -> Timestamp

Panics if the given val is greater than 2^33-1

pub fn value(self) -> u64

produces the timestamp’s value (only the low 33 bits are used)

pub fn likely_wrapped_since(self, since: Self) -> bool

returns true if timestamps are likely to have wrapped around since other, given a current timestamp of self, and given the two timestamp values were taken no more than about 13.3 hours apart (i.e. no more than half the 26.5-ish hours it takes for the wrap around to occur).