[][src]Enum mpeg2ts_reader::psi::CurrentNext

pub enum CurrentNext {
    Current,
    Next,
}

Represents the value of the Transport Stream current_next_indicator field.

Variants

Current

The section version number applies to the currently applicable section data

Next

The section version number applies to the next applicable section data