[][src]Enum mpeg2ts_reader::psi::pat::ProgramDescriptor

pub enum ProgramDescriptor {
    Network {
        pid: Pid,
    },
    Program {
        program_number: u16,
        pid: Pid,
    },
}

Identifiers related to a specific program within the Transport Stream

Variants

Network

this PAT section entry describes where the Network Information Table will be found

Fields of Network

pid: Pid

The PID of NIT section packets

Program

this PAT section entry gives the PID and Program Number of a program within this Transport Stream

Fields of Program

program_number: u16

The program number might represent the 'channel' of the program

pid: Pid

The PID where PMT sections for this program can be found

Methods

impl ProgramDescriptor[src]

pub fn from_bytes(data: &[u8]) -> ProgramDescriptor[src]

panics if fewer than 4 bytes are provided

pub fn pid(&self) -> Pid[src]

produces the Pid of either the NIT or PMT, depending on which type of ProgramDescriptor this is