[][src]Struct mpeg2ts_reader::psi::pat::PatSection

pub struct PatSection<'buf> { /* fields omitted */ }

Sections of the Program Association Table give details of the programs within a transport stream. There may be only one program, or in the case of a broadcast multiplex, there may be many.

Methods

impl<'buf> PatSection<'buf>[src]

pub fn new(data: &'buf [u8]) -> PatSection<'buf>[src]

Create a PatSection, wrapping the given slice, whose methods can parse the section's fields

pub fn programs(
    &self
) -> impl Iterator<Item = ProgramDescriptor> + 'buf
[src]

Returns an iterator over the entries in this program association table section.