[−][src]Struct mpeg2ts_reader::psi::pmt::PmtSection
Sections of the Program Map Table give details of the streams within a particular program
Methods
impl<'buf> PmtSection<'buf>[src]
pub fn from_bytes(data: &'buf [u8]) -> Result<PmtSection<'buf>, DemuxError>[src]
Create a PmtSection, wrapping the given slice, whose methods can parse the section's
fields
pub fn buffer(&self) -> &[u8][src]
Borrow a reference to the buffer containing the underlying PMT section data
pub fn pcr_pid(&self) -> Pid[src]
Returns the Pid of packets that will contain the Program Clock Reference for this program
pub fn descriptors<Desc: Descriptor<'buf> + 'buf>(
&self
) -> impl Iterator<Item = Result<Desc, DescriptorError>> + 'buf[src]
&self
) -> impl Iterator<Item = Result<Desc, DescriptorError>> + 'buf
Returns an iterator over the descriptors attached to this PMT section.
pub fn streams(
&self
) -> impl Iterator<Item = StreamInfo<'buf>>[src]
&self
) -> impl Iterator<Item = StreamInfo<'buf>>
Returns an iterator over the streams of which this program is composed