[−][src]Struct mpeg2ts_reader::psi::pmt::StreamInfo
Details of a particular elementary stream within a program.
stream_typegives an indication of the kind of content carried within the stream- The
elementry_pidproperty allows us to find Transport Stream packets that belong to the elementry stream descriptorsmay provide extra metadata describing some of the stream's properties (for example, the streams 'language' might be given in a descriptor; or it might not)
Methods
impl<'buf> StreamInfo<'buf>[src]
pub fn stream_type(&self) -> StreamType[src]
The type of this stream
pub fn elementary_pid(&self) -> Pid[src]
The Pid that will be used for TS packets containing the data of this stream
pub fn descriptors<Desc: Descriptor<'buf> + 'buf>(
&self
) -> impl Iterator<Item = Result<Desc, DescriptorError>> + 'buf[src]
&self
) -> impl Iterator<Item = Result<Desc, DescriptorError>> + 'buf
Returns an iterator over the descriptors attached to this stream