[][src]Struct mpeg2ts_reader::psi::CrcCheckWholeSectionSyntaxPayloadParser

pub struct CrcCheckWholeSectionSyntaxPayloadParser<P> where
    P: WholeSectionSyntaxPayloadParser
{ /* fields omitted */ }

An implementation of WholeSectionSyntaxPayloadParser which will delegate to another instance of WholeSectionSyntaxPayloadParser only if the CRC of the section data is correct.

Methods

impl<P> CrcCheckWholeSectionSyntaxPayloadParser<P> where
    P: WholeSectionSyntaxPayloadParser
[src]

pub fn new(inner: P) -> CrcCheckWholeSectionSyntaxPayloadParser<P>[src]

create a new CrcCheckWholeSectionSyntaxPayloadParser which wraps and delegates to the given WholeSectionSyntaxPayloadParser instance