[][src]Struct mpeg2ts_reader::psi::DedupSectionSyntaxPayloadParser

pub struct DedupSectionSyntaxPayloadParser<SSPP> where
    SSPP: SectionSyntaxPayloadParser
{ /* fields omitted */ }

A wrapper around some other implementation of SectionSyntaxPayloadParser that passes-through section data, unless the TableSyntaxHeader indicates a version_number which is the same as the last data that was passed though.

This avoids the underlying code needing to re-parse duplicate copies of the section, which are usually inserted periodically in the Transport Stream.

Methods

impl<SSPP> DedupSectionSyntaxPayloadParser<SSPP> where
    SSPP: SectionSyntaxPayloadParser
[src]

pub fn new(inner: SSPP) -> DedupSectionSyntaxPayloadParser<SSPP>[src]

Wraps the given SectionSyntaxPayloadParser in a new DedupSectionSyntaxPayloadParser instance.