[−][src]Struct mpeg2ts_reader::psi::SectionCommonHeader
Header common to all PSI sections, whether they then use 'section syntax' or 'compact syntax'.
Fields
table_id: u8The type of table of which this is a section
section_syntax_indicator: booltrue for 'section syntax,false` for 'compact syntax'.
private_indicator: boolindicates that the data in the table is for private use not defined in ISO/IEC 13818-1
(section types implemented in this crate are to be used with data that has e in
this field, but other crates might be written to support private table sections).
section_length: usizethe number of bytes in the section data immediately following this field (which may be more bytes than will fit into a single TS packet).
Methods
impl SectionCommonHeader[src]
pub const SIZE: usize[src]
The fixed size of the CommonSectionHeader data in the Transport Stream; 3 bytes.
pub fn new(buf: &[u8]) -> SectionCommonHeader[src]
Parses the data in the given slice into a new SectionCommonHeader.
Panics if the slice is not exactly 3 bytes long.