[−][src]Struct mpeg2ts_reader::psi::SectionPacketConsumer
A type for locating the headers of PSI sections, which may be split across multiple TS packets,
and passing each piece to the given SectionProcessor as it is discovered.
Methods
impl<P, Ctx> SectionPacketConsumer<P> where
P: SectionProcessor<Context = Ctx>, [src]
P: SectionProcessor<Context = Ctx>,
pub fn new(parser: P) -> SectionPacketConsumer<P>[src]
Construct a new instance that will delegate processing of section data found in TS packet
payloads to the given SectionProcessor instance.
pub fn consume(&mut self, ctx: &mut Ctx, pk: &Packet)[src]
process the payload of the given TS packet, passing each piece of section data discovered
to the SectionProcessor instance given at time of construction.