pub trait SectionSyntaxPayloadParser {
type Context;
// Required methods
fn start_syntax_section<'a>(
&mut self,
ctx: &mut Self::Context,
header: &SectionCommonHeader,
table_syntax_header: &TableSyntaxHeader<'a>,
data: &'a [u8],
);
fn continue_syntax_section(&mut self, ctx: &mut Self::Context, data: &[u8]);
fn reset(&mut self);
}Expand description
Trait for types that will handle MPEGTS PSI table sections with ‘section syntax’.
Required Associated Types
Required Methods
Sourcefn start_syntax_section<'a>(
&mut self,
ctx: &mut Self::Context,
header: &SectionCommonHeader,
table_syntax_header: &TableSyntaxHeader<'a>,
data: &'a [u8],
)
fn start_syntax_section<'a>( &mut self, ctx: &mut Self::Context, header: &SectionCommonHeader, table_syntax_header: &TableSyntaxHeader<'a>, data: &'a [u8], )
NB the data buffer passed to will include the bytes which are represented by header
and table_syntax_header (in order that the called code can check any CRC that covers the
whole section).
Sourcefn continue_syntax_section(&mut self, ctx: &mut Self::Context, data: &[u8])
fn continue_syntax_section(&mut self, ctx: &mut Self::Context, data: &[u8])
may be called to pass the implementation additional slices of section data, if the complete section was not already passed.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".