[][src]Trait mpeg2ts_reader::psi::WholeSectionSyntaxPayloadParser

pub trait WholeSectionSyntaxPayloadParser {
    type Context;
    fn section<'a>(
        &mut self,
        _: &mut Self::Context,
        header: &SectionCommonHeader,
        table_syntax_header: &TableSyntaxHeader<'a>,
        data: &'a [u8]
    ); }

Trait for types that parse fully reconstructed PSI table sections (which requires the caller to have buffered section data if it spanned multiple TS packets.

Associated Types

type Context

Type of the context object that will be passed to all methods.

Loading content...

Required methods

fn section<'a>(
    &mut self,
    _: &mut Self::Context,
    header: &SectionCommonHeader,
    table_syntax_header: &TableSyntaxHeader<'a>,
    data: &'a [u8]
)

Method that will receive a complete PSI table section, where the data parameter will be header.section_length bytes long

Loading content...

Implementors

impl<P> WholeSectionSyntaxPayloadParser for CrcCheckWholeSectionSyntaxPayloadParser<P> where
    P: WholeSectionSyntaxPayloadParser
[src]

type Context = P::Context

Loading content...