StreamType

Struct StreamType 

pub struct StreamType(pub u8);
The types of Elementary Stream specified in ISO/IEC 13818-1.

As returned by StreamInfo::stream_type().

Tuple Fields

0: u8

Implementations

Source

impl StreamType

pub const ISO_11172_VIDEO: StreamType

ISO/IEC 11172 Video

pub const H262: StreamType

ITU-T Rec. H.262 | ISO/IEC 13818-2 Video or ISO/IEC 11172-2 constrained parameter video stream

pub const ISO_11172_AUDIO: StreamType

ISO/IEC 11172 Audio

pub const ISO_138183_AUDIO: StreamType

ISO/IEC 13818-3 Audio

pub const H222_0_PRIVATE_SECTIONS: StreamType

ITU-T Rec. H.222.0 | ISO/IEC 13818-1 private_sections

pub const H222_0_PES_PRIVATE_DATA: StreamType

ITU-T Rec. H.222.0 | ISO/IEC 13818-1 PES packets containing private data

pub const MHEG: StreamType

ISO/IEC 13522 MHEG

pub const H222_0_DSM_CC: StreamType

ITU-T Rec. H.222.0 | ISO/IEC 13818-1 Annex A DSM-CC

pub const H2221: StreamType

ITU-T Rec. H.222.1

pub const ISO_13818_6_MULTIPROTOCOL_ENCAPSULATION: StreamType

ISO/IEC 13818-6 DSM CC multiprotocol encapsulation

pub const DSMCC_UN_MESSAGES: StreamType

ISO/IEC 13818-6 DSM CC U-N messages

pub const DSMCC_STREAM_DESCRIPTORS: StreamType

ISO/IEC 13818-6 DSM CC stream descriptors

pub const DSMCC_SECTIONS: StreamType

ISO/IEC 13818-6 DSM CC tabled data

pub const H222_0_AUXILIARY: StreamType

ITU-T Rec. H.222.0 | ISO/IEC 13818-1 auxiliary

pub const ADTS: StreamType

ISO/IEC 13818-7 Audio with ADTS transport syntax

pub const ISO_14496_2_VISUAL: StreamType

ISO/IEC 14496-2 Visual

pub const LATM: StreamType

ISO/IEC 14496-3 Audio with the LATM transport syntax as defined in ISO/IEC 14496-3 / AMD 1

pub const FLEX_MUX_PES: StreamType

ISO/IEC 14496-1 SL-packetized stream or FlexMux stream carried in PES packets

pub const FLEX_MUX_ISO_14496_SECTIONS: StreamType

ISO/IEC 14496-1 SL-packetized stream or FlexMux stream carried in ISO/IEC14496_sections.

pub const SYNCHRONIZED_DOWNLOAD_PROTOCOL: StreamType

ISO/IEC 13818-6 Synchronized Download Protocol

pub const METADATA_IN_PES: StreamType

Metadata carried in PES packets

pub const METADATA_IN_METADATA_SECTIONS: StreamType

Metadata carried in metadata_sections

Metadata carried in ISO/IEC 13818-6 Data Carousel

Metadata carried in ISO/IEC 13818-6 Object Carousel

pub const SYNCHRONIZED_DOWNLOAD_PROTOCOL_METADATA: StreamType

Metadata carried in ISO/IEC 13818-6 Synchronized Download Protocol

pub const IPMP: StreamType

IPMP stream (defined in ISO/IEC 13818-11, MPEG-2 IPMP)

pub const H264: StreamType

AVC video stream as defined in ITU-T Rec. H.264 | ISO/IEC 14496-10 Video

pub const AUDIO_WITHOUT_TRANSPORT_SYNTAX: StreamType

ISO/IEC 14496-3 Audio, without using any additional transport syntax, such as DST, ALS and SLS

pub const ISO_14496_17_TEXT: StreamType

ISO/IEC 14496-17 Text

pub const H265: StreamType

ITU-T Rec. H.265 and ISO/IEC 23008-2

pub const CHINESE_VIDEO_STANDARD: StreamType

Chinese Video Standard

pub const ATSC_DOLBY_DIGITAL_AUDIO: StreamType

Dolby Digital (AC-3) audio for ATSC

pub const ATSC_DSMCC_NETWORK_RESOURCES_TABLE: StreamType

ATSC Data Service Table, Network Resources Table

pub const ATSC_DSMCC_SYNCHRONOUS_DATA: StreamType

PES packets containing ATSC streaming synchronous data

pub fn is_pes(self) -> bool

true if packets of a stream with this stream_type will carry data in Packetized Elementary Stream format.