[−][src]Enum mpeg2ts_reader::demultiplex::DemuxError
TODO: this type does not belong here
Variants
NotEnoughDataThe transport stream has a syntax error that means there was not enough data present to parse the requested structure.
Fields of NotEnoughData