pub enum FilterRequest<'a, 'buf: 'a> {
    ByPid(Pid),
    ByStream {
        program_pid: Pid,
        stream_type: StreamType,
        pmt: &'a PmtSection<'buf>,
        stream_info: &'a StreamInfo<'buf>,
    },
    Pmt {
        pid: Pid,
        program_number: u16,
    },
    Nit {
        pid: Pid,
    },
}

Variants

ByPid(Pid)

requests a filter implementation for handling a PID contained in the transport stream that was not announced via other means (PAT/PMT).

ByStream

Fields

program_pid: Pid
stream_type: StreamType
pmt: &'a PmtSection<'buf>
stream_info: &'a StreamInfo<'buf>

requests a filter for the stream with the given details which has just been discovered within a Program Map Table section.

Pmt

Fields

pid: Pid
program_number: u16

Requests a filter implementation for handling Program Map Table sections

Nit

Fields

pid: Pid

requests a filter implementation to handle packets containing Network Information Table data