[−][src]Struct mpeg2ts_reader::demultiplex::FilterChangeset
Owns a queue of FilterChange objects representing pending updates
to the Pid handling of the Demultiplexer.
These changes need to be queued since practically a PacketFilter implementation cannot be
allowed to remove itself from the owning Demultiplex instance while it is in the act of
filtering a packet.
The public interface allows items to be added to the queue, and the internal implementation of
Demultiplex will later remove them.
Methods
impl<F: PacketFilter> FilterChangeset<F>[src]
pub fn insert(&mut self, pid: Pid, filter: F)[src]
Queue the insertion of the given PacketFilter for the given Pid, after the Demultiplex
instance has finished handling the current packet.
pub fn remove(&mut self, pid: Pid)[src]
Queue the removal of the existing PacketFilter for the given Pid, after the Demultiplex
instance has finished handling the current packet.
pub fn is_empty(&self) -> bool[src]
Are there any changes queued in this changeset?