[−][src]Enum mpeg2ts_reader::descriptor::DescriptorError
An error during parsing of a descriptor
Variants
NotEnoughDataThe amount of data available in the buffer is not enough to hold the descriptor's declared size.
Fields of NotEnoughData
TagTooLongForBufferTODO: replace with NotEnoughData
Fields of TagTooLongForBuffer
BufferTooShortThe buffer is too short to even hold the two bytes of generic descriptor header data
Fields of BufferTooShort
buflen: usizethe actual buffer length
UnhandledTagValue(u8)There is no mapping defined of the given descriptor tag value to a Descriptor value.