[−][src]Struct mpeg2ts_reader::descriptor::registration::RegistrationDescriptor
Indicates which kind of syntax any 'private data' within the transport stream will be following
Fields
buf: &'buf [u8]the registration data bytes
Methods
impl<'buf> RegistrationDescriptor<'buf>[src]
pub const TAG: u8[src]
The descriptor tag value which identifies the descriptor as a RegistrationDescriptor.
pub fn new(
_tag: u8,
buf: &'buf [u8]
) -> Result<RegistrationDescriptor<'buf>, DescriptorError>[src]
_tag: u8,
buf: &'buf [u8]
) -> Result<RegistrationDescriptor<'buf>, DescriptorError>
Construct a RegistrationDescriptor instance that will parse the data from the given
slice.
pub fn format_identifier(&self) -> u32[src]
Format identifier value assigned by a Registration Authority.
pub fn additional_identification_info(&self) -> &[u8][src]
borrows a slice of additional_identification_info bytes, whose meaning is defined by
the identifier returned by format_idenfifier().