Enum mpeg2ts_reader::packet::AdaptationControl
source · pub enum AdaptationControl {
Reserved,
PayloadOnly,
AdaptationFieldOnly,
AdaptationFieldAndPayload,
}Expand description
the different values indicating whether a Packet’s adaptation_field() and payload()
methods will return Some or None.
Variants
Reserved
This value is used if the transport stream packet adaptation_control field uses the value
0b00, which is not defined by the spec.
PayloadOnly
indicates that this packet contains a payload, but not an adaptation field
AdaptationFieldOnly
indicates that this packet contains an adaptation field, but not a payload
AdaptationFieldAndPayload
indicates that this packet contains both an adaptation field and a payload
Implementations
sourceimpl AdaptationControl
impl AdaptationControl
pub fn has_payload(self) -> bool