Enum mpeg2ts_reader::packet::AdaptationControl
[−]
[src]
pub enum AdaptationControl {
Reserved,
PayloadOnly,
AdaptationFieldOnly,
AdaptationFieldAndPayload,
}the different values indicating whether a Packet's adaptation_field() and payload()
methods will return Some or None.
Variants
ReservedThis value is used if the transport stream packet adaptation_control field uses the value
0b00, which is not defined by the spec.
PayloadOnlyindicates that this packet contains a payload, but not an adaptation field
AdaptationFieldOnlyindicates that this packet contains an adaptation field, but not a payload
AdaptationFieldAndPayloadindicates that this packet contains both an adaptation field and a payload
Methods
impl AdaptationControl[src]
pub fn has_payload(self) -> bool[src]