Struct mpeg2ts_reader::packet::ContinuityCounter
[−]
[src]
pub struct ContinuityCounter { /* fields omitted */ }A counter value used within a transport stream to detect discontinuities in a sequence of packets.
The continuity counter should increase by one for each packet with a given PID for which
adaptation_control indicates that a payload should be present.
Methods
impl ContinuityCounter[src]
pub fn new(count: u8) -> ContinuityCounter[src]
Panics if the given value is greater than 15.
pub fn count(&self) -> u8[src]
Returns this counter's value, which will be between 0 and 15 inclusive.
pub fn follows(&self, other: ContinuityCounter) -> bool[src]
true iff the given ContinuityCounter value follows this one. Note that the maximum counter
value is 15, and the counter 'wraps around':
let a = ContinuityCounter::new(0); let b = ContinuityCounter::new(15); assert!(a.follows(b)); // after 15, counter wraps around to 0