[−][src]Enum mpeg2ts_reader::pes::Copyright
Indicates the copyright status of the contents of the Elementary Stream packet.
Returned by PesParsedContents.copyright()
Variants
ProtectedContent of this Elementry Stream is protected by copyright
UndefinedCopyright protection of the content of this Elementary Stream is not defined