[−][src]Enum mpeg2ts_reader::pes::DataAlignment
Indicates if the start of some 'unit' of Elementary Stream content is immediately at the start of the PES packet payload.
Returned by
PesParsedContents.data_alignment_indicator()
Variants
AlignedAccess Units are aligned to the start of the PES packet payload
NotAlignedAccess Units are might not be aligned to the start of the PES packet payload