pub enum PesContents<'buf> {
    Parsed(Option<PesParsedContents<'buf>>),
    Payload(&'buf [u8]),
}
Either PesContents::Payload, when the PesHeader has no extra fields, or PesContents::Parsed, when the header provides additional optional fields exposed in a ParsedPesContents object.

Example

To access initial portion of the payload of a PES packet, given the PesHeader (and ignoring any fields that might be present in ParsedPesContents), you could write,

fn handle_payload(header: PesHeader) {
    match header.contents() {
        PesContents::Payload(buf) => do_something(buf),
        PesContents::Parsed(Some(parsed)) => do_something(parsed.payload()),
        _ => println!("error: couldn't access PES payload!"),
    }
}

Variants

Parsed(Option<PesParsedContents<'buf>>)

Payload(&'buf [u8])