[−][src]Enum mpeg2ts_reader::pes::PesError
Errors which may be encountered while processing PES data.
Variants
FieldNotPresentThe value of an optional field was requested, but the field is not actually present in the given PES data
PtsDtsFlagsInvalidThe pts_dts_flags field of the PES packet signals that DTS is present and PTS is not,
which not a valid combination
NotEnoughDataThere is not enough data in the buffer to hold the expected syntax element
Fields of NotEnoughData
MarkerBitNotSetMarker bits are expected to always have the value 1 -- the value 0 presumably implies
a parsing error.