[−][src]Enum mpeg2ts_reader::pes::PesLength
Type for the length of a PES packet
Variants
UnboundedThe PES packet continues until the next TS packet that has payload_unit_start_indicator
set. According to the spec, only valid for video streams (but really, it is needed in
case the size of the pes packet will exceed the 16 bits of this field -- around 65k bytes).
Bounded(NonZeroU16)The PES packet's length (likely to exceed the size of the TS packet that contains the PES packet header).