[][src]Enum mpeg2ts_reader::pes::TimestampError

pub enum TimestampError {
    IncorrectPrefixBits {
        expected: u8,
        actual: u8,
    },
    MarkerBitNotSet {
        bit_number: u8,
    },
}

Detail about the formatting problem which prevented a Timestamp value being parsed.

Variants

IncorrectPrefixBits

Parsing the timestamp failed because the 'prefix-bit' values within the timestamp did not have the expected values

Fields of IncorrectPrefixBits

expected: u8

expected prefix-bits for this timestamp

actual: u8

the actual, incorrect bits that were present

MarkerBitNotSet

Parsing the timestamp failed because a 'marker-bit' value within the timestamp did not have the expected value

Fields of MarkerBitNotSet

bit_number: u8

the bit-index of the bit which should have been 1, but was found to be 0