[−][src]Enum mpeg2ts_reader::pes::TimestampError
Detail about the formatting problem which prevented a Timestamp
value being parsed.
Variants
IncorrectPrefixBitsParsing the timestamp failed because the 'prefix-bit' values within the timestamp did not have the expected values
Fields of IncorrectPrefixBits
MarkerBitNotSetParsing the timestamp failed because a 'marker-bit' value within the timestamp did not have the expected value
Fields of MarkerBitNotSet
bit_number: u8the bit-index of the bit which should have been 1, but was found to be 0