pub struct PesHeader<'buf> { /* private fields */ }
Header at the start of every PES packet.

The header identifies,

  • The stream identifier, returned by stream_id()
  • The the size of the packet, returned by pes_packet_length(), which may well be larger than the size of the payload buffer obtained from the header (the payload is likely split across multiple Transport Stream packets)

In addition, the header may provide access to either

  • an additional set of header data followed by a payload, when contents() returns PesContents::Parsed
  • just a payload on its own, when contents() returns PesContents::Payload

Implementations