[−][src]Struct mpeg2ts_reader::pes::Timestamp
A 33-bit Elementary Stream timestamp, used to represent PTS and DTS values which may appear in an Elementary Stream header.
Methods
impl Timestamp[src]
pub fn from_pts_bytes(buf: &[u8]) -> Result<Timestamp, TimestampError>[src]
Parse a Presentation Time Stamp value from the 5 bytes at the start of the given slice
Panics if fewer than 5 bytes given
pub fn from_dts_bytes(buf: &[u8]) -> Result<Timestamp, TimestampError>[src]
Parse a Decode Time Stamp value from the 5 bytes at the start of the given slice
Panics if fewer than 5 bytes given
pub fn from_bytes(buf: &[u8]) -> Result<Timestamp, TimestampError>[src]
Parse a Time Stamp value from the 5 bytes at the start of the given slice, without checking
the 4-bit prefix for any particular value (the from_pts_bytes() and from_dts_bytes()
methods, in contrast, do check that the expected prefix bits are present).
Panics if fewer than 5 bytes given
pub fn from_u64(val: u64) -> Timestamp[src]
Panics if the given val is greater than 2^33-1
pub fn value(self) -> u64[src]
produces the timestamp's value (only the low 33 bits are used)