[−][src]Trait mpeg2ts_reader::pes::ElementaryStreamConsumer
Trait for types that will receive call-backs as pieces of a specific elementary stream are encounted within a transport stream.
Instances of this type are registered with a
PesPacketConsumer, which itself is responsible for
extracting elementary stream data from transport stream packets.
Required methods
fn start_stream(&mut self)
called before the first call to begin_packet()
fn begin_packet(&mut self, header: PesHeader)
called with the header at the start of the PES packet, which may not contain the complete PES payload
fn continue_packet(&mut self, data: &[u8])
called after an earlier call to begin_packet() when another part of the packet's payload
data is found in the Transport Stream.
fn end_packet(&mut self)
called when a PES packet ends, prior to the next call to begin_packet() (if any).
fn continuity_error(&mut self)
called when gap is seen in continuity counter values for this stream, indicating that some data in the original Transpport Stream did not reach the parser.