[−][src]Struct mpeg2ts_reader::psi::SectionSyntaxSectionProcessor
An implementation of SectionProcessor to be used for sections that implement 'section syntax'
(rather than 'compact syntax').
Parses the TableSyntaxHeader at the front of the section data, and then delegates handling
to the SectionSyntaxPayloadParser instance given at construction time.
Methods
impl<SP> SectionSyntaxSectionProcessor<SP> where
SP: SectionSyntaxPayloadParser, [src]
SP: SectionSyntaxPayloadParser,
pub fn new(payload_parser: SP) -> SectionSyntaxSectionProcessor<SP>[src]
Wraps the given SectionSyntaxPayloadParser instance in a new
SectionSyntaxSectionProcessor.