[−][src]Trait mpeg2ts_reader::psi::SectionSyntaxPayloadParser
Trait for types that will handle MPEGTS PSI table sections with 'section syntax'.
Associated Types
type Context
The type of the context object passed to all methods
Required methods
fn start_syntax_section<'a>(
&mut self,
ctx: &mut Self::Context,
header: &SectionCommonHeader,
table_syntax_header: &TableSyntaxHeader<'a>,
data: &'a [u8]
)
&mut self,
ctx: &mut Self::Context,
header: &SectionCommonHeader,
table_syntax_header: &TableSyntaxHeader<'a>,
data: &'a [u8]
)
NB the data buffer passed to will include the bytes which are represented by header
and table_syntax_header (in order that the called code can check any CRC that covers the
whole section).
fn continue_syntax_section<'a>(
&mut self,
ctx: &mut Self::Context,
data: &'a [u8]
)
&mut self,
ctx: &mut Self::Context,
data: &'a [u8]
)
may be called to pass the implementation additional slices of section data, if the complete section was not already passed.
fn reset(&mut self)
called if there is a problem in the transport stream that means any in-progress section data should be discarded.
Implementors
impl<P> SectionSyntaxPayloadParser for BufferSectionSyntaxParser<P> where
P: WholeSectionSyntaxPayloadParser, [src]
P: WholeSectionSyntaxPayloadParser,
type Context = P::Context
fn start_syntax_section<'a>(
&mut self,
ctx: &mut Self::Context,
header: &SectionCommonHeader,
table_syntax_header: &TableSyntaxHeader<'a>,
data: &'a [u8]
)[src]
&mut self,
ctx: &mut Self::Context,
header: &SectionCommonHeader,
table_syntax_header: &TableSyntaxHeader<'a>,
data: &'a [u8]
)
fn continue_syntax_section<'a>(
&mut self,
ctx: &mut Self::Context,
data: &'a [u8]
)[src]
&mut self,
ctx: &mut Self::Context,
data: &'a [u8]
)
fn reset(&mut self)[src]
impl<SSPP> SectionSyntaxPayloadParser for DedupSectionSyntaxPayloadParser<SSPP> where
SSPP: SectionSyntaxPayloadParser, [src]
SSPP: SectionSyntaxPayloadParser,
type Context = SSPP::Context
fn start_syntax_section<'a>(
&mut self,
ctx: &mut Self::Context,
header: &SectionCommonHeader,
table_syntax_header: &TableSyntaxHeader<'a>,
data: &'a [u8]
)[src]
&mut self,
ctx: &mut Self::Context,
header: &SectionCommonHeader,
table_syntax_header: &TableSyntaxHeader<'a>,
data: &'a [u8]
)
fn continue_syntax_section<'a>(
&mut self,
ctx: &mut Self::Context,
data: &'a [u8]
)[src]
&mut self,
ctx: &mut Self::Context,
data: &'a [u8]
)